package com.yijia.market.mapper;


import com.yijia.market.domain.MarkertPlan;

import java.util.List;

/**
 * 营销方案Mapper接口
 * 
 * @author yijia
 * @date 2020-12-22
 */
public interface MarkertPlanMapper 
{
    /**
     * 查询营销方案
     * 
     * @param id 营销方案ID
     * @return 营销方案
     */
    public MarkertPlan selectMarkertPlanById(Long id);

    /**
     * 查询营销方案列表
     * 
     * @param markertPlan 营销方案
     * @return 营销方案集合
     */
    public List<MarkertPlan> selectMarkertPlanList(MarkertPlan markertPlan);

    /**
     * 新增营销方案
     * 
     * @param markertPlan 营销方案
     * @return 结果
     */
    public int insertMarkertPlan(MarkertPlan markertPlan);

    /**
     * 修改营销方案
     * 
     * @param markertPlan 营销方案
     * @return 结果
     */
    public int updateMarkertPlan(MarkertPlan markertPlan);

    /**
     * 删除营销方案
     * 
     * @param id 营销方案ID
     * @return 结果
     */
    public int deleteMarkertPlanById(Long id);

    /**
     * 批量删除营销方案
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteMarkertPlanByIds(Long[] ids);
}
